E4XML/XMLWriterBase.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 42
23b45a742e17
--- a/E4XML/XMLWriterBase.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/E4XML/XMLWriterBase.py	Sat Jan 02 17:09:08 2010 +0000
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a base class for all of eric4s XML writers.
+Module implementing a base class for all of eric5s XML writers.
 """
 
 import os
@@ -12,7 +12,7 @@
 
 class XMLWriterBase(object):
     """
     Class implementing a base class for all of eric4s XML writers.
     """
     def __init__(self, file):
         """
@@ -224,4 +224,4 @@
         @param indent indentation level for prettier output (integer)
         """
         self._write('%s<pickle method="pickle" encoding="base64">%s</pickle>' % \
-            ("  " * indent, pickle.dumps(value).encode('base64')))
+            ("  " * indent, pickle.dumps(value).encode('base64')))
\ No newline at end of file
@@ -12,7 +12,7 @@
 class XMLWriterBase(object):
     """
-    Class implementing a base class for all of eric4s XML writers.
+    Class implementing a base class for all of eric5s XML writers.
     """
     def __init__(self, file):

eric ide

mercurial